@@ -109,7 +109,7 @@ class SMBPendingMsg:
 		await self.__destroy_message(SMBPendingTimeout())
 
 	async def __destroy_message(self, problem):
-		self.OutstandingResponses[self.message_id] = problem
+		self.OutstandingResponses[self.message_id] = (None, problem)
 		if self.message_id in self.OutstandingResponsesEvent:
 			self.OutstandingResponsesEvent[self.message_id].set()
 		return
@@ -251,8 +251,8 @@ class SMBConnection:
 			}
 		return None
 
-	async def __pending_task(self, message_id, timeout = 5):
-		await asyncio.sleep(timeout)
+	#async def __pending_task(self, message_id, timeout = 5):
+	#	await asyncio.sleep(timeout)
 		
 
 	async def __handle_smb_in(self):
@@ -269,7 +269,7 @@ class SMBConnection:
 					logger.debug('__handle_smb_in got error from transport layer %s' % err)
 					#setting all outstanding events to finished
 					for mid in self.OutstandingResponsesEvent:
-						self.OutstandingResponses[mid] = None, err
+						self.OutstandingResponses[mid] = (None, err)
 						self.OutstandingResponsesEvent[mid].set()
 
 					await self.terminate()
@@ -336,7 +336,7 @@ class SMBConnection:
 					raise Exception('Encrypted SMBv2 message recieved, but encryption is not yet supported!')
 				
 				if msg.header.Status == NTStatus.PENDING:
-					self.pending_table[msg.header.MessageId] = SMBPendingMsg(msg.header.MessageId, self.OutstandingResponses, self.OutstandingResponsesEvent)
+					self.pending_table[msg.header.MessageId] = SMBPendingMsg(msg.header.MessageId, self.OutstandingResponses, self.OutstandingResponsesEvent, timeout = self.target.SMBPendingTimeout, max_renewal=self.target.SMBPendingMaxRenewal)
 					await self.pending_table[msg.header.MessageId].run()
 					continue
 
@@ -704,6 +704,11 @@ class SMBConnection:
 				maxiter -= 1
 			
 			if rply.header.Status == NTStatus.SUCCESS:
+				command.Buffer, res, err  = await self.gssapi.authenticate(authdata)
+				if err is not None:
+					raise err
+
+
 				if self.gssapi.is_guest() is True:
 					self.signing_required = False
 
@@ -742,7 +747,7 @@ class SMBConnection:
 		"""
 		if message_id not in self.OutstandingResponses:
 			logger.log(1, 'Waiting on messageID : %s' % message_id)
-			await self.OutstandingResponsesEvent[message_id].wait()
+			await self.OutstandingResponsesEvent[message_id].wait() #TODO: add timeout here?
 			
 		msg, msg_data = self.OutstandingResponses.pop(message_id)
 		if msg is None:
